=== modified file 'src/seat-xlocal.c'
--- src/seat-xlocal.c	2013-10-28 17:19:00 +0000
+++ src/seat-xlocal.c	2013-12-11 03:28:54 +0000
@@ -14,6 +14,7 @@
 #include "seat-xlocal.h"
 #include "configuration.h"
 #include "x-server-local.h"
+#include "unity-system-compositor.h"
 #include "plymouth.h"
 #include "vt.h"
 
@@ -36,44 +37,71 @@
 static gboolean
 seat_xlocal_start (Seat *seat)
 {
-   
     return SEAT_CLASS (seat_xlocal_parent_class)->start (seat);
 }
 
 static void
-x_server_ready_cb (XServerLocal *x_server, Seat *seat)
+display_server_ready_cb (DisplayServer *display_server, Seat *seat)
 {
     /* Quit Plymouth */
     plymouth_quit (TRUE);
 }
 
 static void
-x_server_transition_plymouth_cb (XServerLocal *x_server, Seat *seat)
+display_server_transition_plymouth_cb (DisplayServer *display_server, Seat *seat)
 {
     /* Quit Plymouth if we didn't do the transition */
     if (plymouth_get_is_running ())
         plymouth_quit (FALSE);
 
-    g_signal_handlers_disconnect_matched (x_server, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, x_server_transition_plymouth_cb, NULL);
+    g_signal_handlers_disconnect_matched (display_server, G_SIGNAL_MATCH_FUNC, 0, 0, NULL, display_server_transition_plymouth_cb, NULL);
+}
+
+static gint
+get_vt (Seat *seat, DisplayServer *display_server)
+{
+    gint vt = -1;
+
+    /* If Plymouth is running, stop it */
+    if (plymouth_get_is_active () && plymouth_has_active_vt ())
+    {
+        gint active_vt = vt_get_active ();
+        if (active_vt >= vt_get_min ())
+        {
+            vt = active_vt;
+            g_signal_connect (display_server, "ready", G_CALLBACK (display_server_ready_cb), seat);
+            g_signal_connect (display_server, "stopped", G_CALLBACK (display_server_transition_plymouth_cb), seat);
+            plymouth_deactivate ();
+        }
+        else
+            l_debug (seat, "Plymouth is running on VT %d, but this is less than the configured minimum of %d so not replacing it", active_vt, vt_get_min ());
+    }
+    if (plymouth_get_is_active ())
+        plymouth_quit (FALSE);
+    if (vt < 0)
+        vt = vt_get_unused ();
+
+    return vt;
 }
 
 static DisplayServer *
-seat_xlocal_create_display_server (Seat *seat, const gchar *session_type)
-{  
-    if (strcmp (session_type, "x") != 0)
-        return NULL;
-
+create_x_server (Seat *seat)
+{
     XServerLocal *x_server;
     const gchar *command = NULL, *layout = NULL, *config_file = NULL, *xdmcp_manager = NULL, *key_name = NULL, *xdg_seat = NULL;
     gboolean allow_tcp;
-    gint vt = -1, port = 0;
+    gint vt, port = 0;
+
+    x_server = x_server_local_new ();
+
+    vt = get_vt (seat, DISPLAY_SERVER (x_server));
+    if (vt >= 0)
+        x_server_local_set_vt (x_server, vt);
 
     if (vt > 0)
         l_debug (seat, "Starting local X display on VT %d", vt);
     else
         l_debug (seat, "Starting local X display");
-  
-    x_server = x_server_local_new ();
 
     /* If running inside an X server use Xephyr instead */
     if (g_getenv ("DISPLAY"))
@@ -83,27 +111,6 @@
     if (command)
         x_server_local_set_command (x_server, command);
 
-    /* If Plymouth is running, stop it */
-    if (plymouth_get_is_active () && plymouth_has_active_vt ())
-    {
-        gint active_vt = vt_get_active ();
-        if (active_vt >= vt_get_min ())
-        {
-            vt = active_vt;
-            g_signal_connect (x_server, "ready", G_CALLBACK (x_server_ready_cb), seat);
-            g_signal_connect (x_server, "stopped", G_CALLBACK (x_server_transition_plymouth_cb), seat);
-            plymouth_deactivate ();
-        }
-        else
-            l_debug (seat, "Plymouth is running on VT %d, but this is less than the configured minimum of %d so not replacing it", active_vt, vt_get_min ());
-    }
-    if (plymouth_get_is_active ())
-        plymouth_quit (FALSE);
-    if (vt < 0)
-        vt = vt_get_unused ();
-    if (vt >= 0)
-        x_server_local_set_vt (x_server, vt);
-
     layout = seat_get_string_property (seat, "xserver-layout");
     if (layout)
         x_server_local_set_layout (x_server, layout);
@@ -166,6 +173,55 @@
     return DISPLAY_SERVER (x_server);
 }
 
+static DisplayServer *
+create_unity_system_compositor (Seat *seat)
+{
+    UnitySystemCompositor *compositor;
+    const gchar *command;
+    gchar *socket_name;
+    gint vt, timeout, i;
+
+    compositor = unity_system_compositor_new ();
+
+    command = seat_get_string_property (seat, "unity-compositor-command");
+    if (command)
+        unity_system_compositor_set_command (compositor, command);
+
+    timeout = seat_get_integer_property (seat, "unity-compositor-timeout");
+    if (timeout <= 0)
+        timeout = 60;
+    unity_system_compositor_set_timeout (compositor, timeout);
+
+    vt = get_vt (seat, DISPLAY_SERVER (compositor));
+    if (vt >= 0)
+        unity_system_compositor_set_vt (compositor, vt);
+  
+    for (i = 0; ; i++)
+    {
+        socket_name = g_strdup_printf ("/tmp/lightdm-mir-%d", i);
+        if (!g_file_test (socket_name, G_FILE_TEST_EXISTS))
+            break;
+    }
+    unity_system_compositor_set_socket (compositor, socket_name);
+    g_free (socket_name);
+
+    return DISPLAY_SERVER (compositor);
+}
+
+static DisplayServer *
+seat_xlocal_create_display_server (Seat *seat, const gchar *session_type)
+{
+    if (strcmp (session_type, "x") == 0)
+        return create_x_server (seat);
+    else if (strcmp (session_type, "mir") == 0)
+        return create_unity_system_compositor (seat);
+    else
+    {
+        l_warning (seat, "Can't create unsupported display server '%s'", session_type);
+        return NULL;
+    }
+}
+
 static Greeter *
 seat_xlocal_create_greeter_session (Seat *seat)
 {

=== modified file 'src/unity-system-compositor.c'
--- src/unity-system-compositor.c	2013-12-11 00:05:31 +0000
+++ src/unity-system-compositor.c	2013-12-11 03:28:54 +0000
@@ -21,6 +21,7 @@
 #include "unity-system-compositor.h"
 #include "configuration.h"
 #include "process.h"
+#include "greeter.h"
 #include "vt.h"
 
 struct UnitySystemCompositorPrivate
@@ -165,6 +166,36 @@
     return UNITY_SYSTEM_COMPOSITOR (server)->priv->vt;
 }
 
+static void
+unity_system_compositor_connect_session (DisplayServer *display_server, Session *session)
+{
+    UnitySystemCompositor *compositor = UNITY_SYSTEM_COMPOSITOR (display_server);
+    const gchar *name;
+
+    if (compositor->priv->socket)
+        session_set_env (session, "MIR_SOCKET", compositor->priv->socket);
+    if (IS_GREETER (session))
+        name = "greeter-0";
+    else
+        name = "session-0";
+    session_set_env (session, "MIR_SERVER_NAME", name);
+
+    if (compositor->priv->vt >= 0)
+    {
+        gchar *value = g_strdup_printf ("%d", compositor->priv->vt);
+        session_set_env (session, "XDG_VTNR", value);
+        g_free (value);
+    }
+}
+
+static void
+unity_system_compositor_disconnect_session (DisplayServer *display_server, Session *session)
+{
+    session_unset_env (session, "MIR_SOCKET");
+    session_unset_env (session, "MIR_SERVER_NAME");
+    session_unset_env (session, "XDG_VTNR");
+}
+
 static gchar *
 get_absolute_command (const gchar *command)
 {
@@ -478,6 +509,8 @@
     DisplayServerClass *display_server_class = DISPLAY_SERVER_CLASS (klass);
 
     display_server_class->get_vt = unity_system_compositor_get_vt;
+    display_server_class->connect_session = unity_system_compositor_connect_session;
+    display_server_class->disconnect_session = unity_system_compositor_disconnect_session;
     display_server_class->start = unity_system_compositor_start;
     display_server_class->stop = unity_system_compositor_stop;
     object_class->finalize = unity_system_compositor_finalize;

=== modified file 'tests/scripts/mir-autologin.conf'
--- tests/scripts/mir-autologin.conf	2013-10-21 22:43:11 +0000
+++ tests/scripts/mir-autologin.conf	2013-12-11 03:28:54 +0000
@@ -1,5 +1,5 @@
 #
-# Check can't automatically log into a Mir session from a VT based seat
+# Check can automatically log into a Mir session from a VT based seat
 #
 
 [SeatDefaults]
@@ -8,25 +8,15 @@
 
 #?RUNNER DAEMON-START
 
-# (session fails to start)
-
-# X server starts
-#?XSERVER-0 START VT=7
-
-# Daemon connects when X server is ready
-#?*XSERVER-0 INDICATE-READY
-#?XSERVER-0 INDICATE-READY
-#?XSERVER-0 ACCEPT-CONNECT
-
-# Greeter starts
-#?GREETER-X-0 START XDG_SEAT=seat0 XDG_VTNR=7 XDG_SESSION_CLASS=greeter
-#?XSERVER-0 ACCEPT-CONNECT
-#?GREETER-X-0 CONNECT-XSERVER
-#?GREETER-X-0 CONNECT-TO-DAEMON
-#?GREETER-X-0 CONNECTED-TO-DAEMON
+# System compositor starts
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/lightdm-mir-0 VT=7 XDG_VTNR=7
+#?*UNITY-SYSTEM-COMPOSITOR READY
+
+# Session starts
+#?SESSION-MIR-session-0 START XDG_SEAT=seat0 XDG_VTNR=7 DESKTOP_SESSION=mir USER=have-password1
 
 # Cleanup
 #?*STOP-DAEMON
-#?GREETER-X-0 TERMINATE SIGNAL=15
-#?XSERVER-0 TERMINATE SIGNAL=15
+#?SESSION-MIR-session-0 TERMINATE SIGNAL=15
+#?UNITY-SYSTEM-COMPOSITOR TERMINATE SIGNAL=15
 #?RUNNER DAEMON-EXIT STATUS=0

=== modified file 'tests/scripts/mir-greeter.conf'
--- tests/scripts/mir-greeter.conf	2013-07-26 05:14:58 +0000
+++ tests/scripts/mir-greeter.conf	2013-12-11 03:28:54 +0000
@@ -1,10 +1,20 @@
 #
-# Check can't run a Mir greeter from a VT based seat
+# Check can run a Mir greeter from a VT based seat
 #
 
 #?RUNNER DAEMON-START
 
-# (greeter fails to start)
-
-# Daemon stops with error
-#?RUNNER DAEMON-EXIT STATUS=1
+# System compositor starts
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/lightdm-mir-0 VT=7 XDG_VTNR=7
+#?*UNITY-SYSTEM-COMPOSITOR READY
+
+# Greeter starts
+#?GREETER-MIR-greeter-0 START XDG_SEAT=seat0 XDG_VTNR=7 XDG_SESSION_CLASS=greeter
+#?GREETER-MIR-greeter-0 CONNECT-TO-DAEMON
+#?GREETER-MIR-greeter-0 CONNECTED-TO-DAEMON
+
+# Cleanup
+#?*STOP-DAEMON
+#?GREETER-MIR-greeter-0 TERMINATE SIGNAL=15
+#?UNITY-SYSTEM-COMPOSITOR TERMINATE SIGNAL=15
+#?RUNNER DAEMON-EXIT STATUS=0

=== modified file 'tests/scripts/mir-session.conf'
--- tests/scripts/mir-session.conf	2013-10-21 22:43:11 +0000
+++ tests/scripts/mir-session.conf	2013-12-11 03:28:54 +0000
@@ -1,5 +1,5 @@
 #
-# Check can't login into a Mir session on a VT based seat
+# Check can login into a Mir session on a VT based seat
 #
 
 [SeatDefaults]
@@ -25,10 +25,24 @@
 # Attempt to log into account
 #?*GREETER-X-0 AUTHENTICATE USERNAME=no-password1
 #?GREETER-X-0 AUTHENTICATION-COMPLETE USERNAME=no-password1 AUTHENTICATED=TRUE
-#?*GREETER-X-0 SESSION-FAILED
+#?*GREETER-X-0 START-SESSION
+
+# System compositor starts
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/lightdm-mir-0 VT=8 XDG_VTNR=8
+#?*UNITY-SYSTEM-COMPOSITOR READY
+
+# Switch to system compositor
+#?VT ACTIVATE VT=8
+
+# Greeter terminates
+#?GREETER-X-0 TERMINATE SIGNAL=15
+#?XSERVER-0 TERMINATE SIGNAL=15
+
+# Session starts
+#?SESSION-MIR-session-0 START XDG_SEAT=seat0 XDG_VTNR=8 DESKTOP_SESSION=mir USER=no-password1
 
 # Cleanup
 #?*STOP-DAEMON
-#?GREETER-X-0 TERMINATE SIGNAL=15
-#?XSERVER-0 TERMINATE SIGNAL=15
+#?SESSION-MIR-session-0 TERMINATE SIGNAL=15
+#?UNITY-SYSTEM-COMPOSITOR TERMINATE SIGNAL=15
 #?RUNNER DAEMON-EXIT STATUS=0

=== modified file 'tests/scripts/unity-autologin.conf'
--- tests/scripts/unity-autologin.conf	2013-10-28 17:19:00 +0000
+++ tests/scripts/unity-autologin.conf	2013-12-11 03:28:54 +0000
@@ -10,7 +10,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # X server starts

=== modified file 'tests/scripts/unity-compositor-command.conf'
--- tests/scripts/unity-compositor-command.conf	2013-10-28 18:31:41 +0000
+++ tests/scripts/unity-compositor-command.conf	2013-12-11 03:28:54 +0000
@@ -10,7 +10,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7 TEST=TRUE
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7 TEST=TRUE
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # X server starts

=== modified file 'tests/scripts/unity-compositor-fail-ready.conf'
--- tests/scripts/unity-compositor-fail-ready.conf	2013-11-18 20:41:55 +0000
+++ tests/scripts/unity-compositor-fail-ready.conf	2013-12-11 03:28:54 +0000
@@ -9,7 +9,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts but doesn't indicate it is ready
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 
 # Timeout and compositor is stopped
 #?UNITY-SYSTEM-COMPOSITOR TERMINATE SIGNAL=15

=== modified file 'tests/scripts/unity-compositor-fail-start.conf'
--- tests/scripts/unity-compositor-fail-start.conf	2013-11-18 20:41:55 +0000
+++ tests/scripts/unity-compositor-fail-start.conf	2013-12-11 03:28:54 +0000
@@ -11,7 +11,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor fails to start
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?UNITY-SYSTEM-COMPOSITOR EXIT CODE=1
 
 # Cleanup

=== modified file 'tests/scripts/unity-compositor-fallback.conf'
--- tests/scripts/unity-compositor-fallback.conf	2013-11-25 21:38:53 +0000
+++ tests/scripts/unity-compositor-fallback.conf	2013-12-11 03:28:54 +0000
@@ -11,11 +11,11 @@
 #?RUNNER DAEMON-START
 
 # System compositor fails to start
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?UNITY-SYSTEM-COMPOSITOR EXIT CODE=1
 
 # System compositor fails to start a second time
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?UNITY-SYSTEM-COMPOSITOR EXIT CODE=1
 
 # X server starts in VT mode

=== modified file 'tests/scripts/unity-compositor-mir-next-session.conf'
--- tests/scripts/unity-compositor-mir-next-session.conf	2013-10-28 18:31:41 +0000
+++ tests/scripts/unity-compositor-mir-next-session.conf	2013-12-11 03:28:54 +0000
@@ -11,7 +11,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # Greeter session

=== modified file 'tests/scripts/unity-compositor-next-session.conf'
--- tests/scripts/unity-compositor-next-session.conf	2013-10-28 18:31:41 +0000
+++ tests/scripts/unity-compositor-next-session.conf	2013-12-11 03:28:54 +0000
@@ -11,7 +11,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # Greeter session

=== modified file 'tests/scripts/unity-login.conf'
--- tests/scripts/unity-login.conf	2013-10-28 18:31:41 +0000
+++ tests/scripts/unity-login.conf	2013-12-11 03:28:54 +0000
@@ -9,7 +9,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # X server starts

=== modified file 'tests/scripts/unity-mir-autologin.conf'
--- tests/scripts/unity-mir-autologin.conf	2013-10-28 17:19:00 +0000
+++ tests/scripts/unity-mir-autologin.conf	2013-12-11 03:28:54 +0000
@@ -10,7 +10,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # Session starts

=== modified file 'tests/scripts/unity-mir-greeter-mir-session.conf'
--- tests/scripts/unity-mir-greeter-mir-session.conf	2013-10-28 18:31:41 +0000
+++ tests/scripts/unity-mir-greeter-mir-session.conf	2013-12-11 03:28:54 +0000
@@ -9,7 +9,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # Greeter starts

=== modified file 'tests/scripts/unity-mir-greeter-x-session.conf'
--- tests/scripts/unity-mir-greeter-x-session.conf	2013-10-28 18:31:41 +0000
+++ tests/scripts/unity-mir-greeter-x-session.conf	2013-12-11 03:28:54 +0000
@@ -9,7 +9,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # Greeter starts

=== modified file 'tests/scripts/unity-mir-lock-seat.conf'
--- tests/scripts/unity-mir-lock-seat.conf	2013-11-25 21:58:43 +0000
+++ tests/scripts/unity-mir-lock-seat.conf	2013-12-11 03:28:54 +0000
@@ -10,7 +10,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # Session starts

=== modified file 'tests/scripts/unity-mir-session-x-greeter.conf'
--- tests/scripts/unity-mir-session-x-greeter.conf	2013-10-28 18:31:41 +0000
+++ tests/scripts/unity-mir-session-x-greeter.conf	2013-12-11 03:28:54 +0000
@@ -9,7 +9,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # X server starts

=== modified file 'tests/scripts/unity-plymouth.conf'
--- tests/scripts/unity-plymouth.conf	2013-10-28 17:19:00 +0000
+++ tests/scripts/unity-plymouth.conf	2013-12-11 03:28:54 +0000
@@ -20,7 +20,7 @@
 #?PLYMOUTH QUIT RETAIN-SPLASH=TRUE
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # X server starts

=== modified file 'tests/scripts/unity-switch.conf'
--- tests/scripts/unity-switch.conf	2013-10-28 18:31:41 +0000
+++ tests/scripts/unity-switch.conf	2013-12-11 03:28:54 +0000
@@ -10,7 +10,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # X server starts

=== modified file 'tests/scripts/unity-xdg-seat.conf'
--- tests/scripts/unity-xdg-seat.conf	2013-10-28 17:19:00 +0000
+++ tests/scripts/unity-xdg-seat.conf	2013-12-11 03:28:54 +0000
@@ -11,7 +11,7 @@
 #?RUNNER DAEMON-START
 
 # System compositor starts
-#?UNITY-SYSTEM-COMPOSITOR START VT=7 XDG_VTNR=7
+#?UNITY-SYSTEM-COMPOSITOR START FILE=/tmp/mir_socket VT=7 XDG_VTNR=7
 #?*UNITY-SYSTEM-COMPOSITOR READY
 
 # X server starts

=== modified file 'tests/src/unity-system-compositor.c'
--- tests/src/unity-system-compositor.c	2013-09-30 20:22:11 +0000
+++ tests/src/unity-system-compositor.c	2013-12-11 03:28:54 +0000
@@ -141,6 +141,7 @@
     GString *status_text;
     gboolean test = FALSE;
     int vt_number = -1;
+    const gchar *file = NULL;
 
 #if !defined(GLIB_VERSION_2_36)
     g_type_init ();
@@ -174,7 +175,7 @@
         }
         else if (strcmp (arg, "--file") == 0)
         {
-            /*file = argv[i+1];*/
+            file = argv[i+1];
             i++;
         }
         else if (strcmp (arg, "--test") == 0)
@@ -186,6 +187,8 @@
     g_io_add_watch (g_io_channel_unix_new (from_dm_fd), G_IO_IN, read_message_cb, NULL);
 
     status_text = g_string_new ("UNITY-SYSTEM-COMPOSITOR START");
+    if (file)
+        g_string_append_printf (status_text, " FILE=%s", file);
     if (vt_number >= 0)
         g_string_append_printf (status_text, " VT=%d", vt_number);
     if (g_getenv ("XDG_VTNR"))

